@@ -1,10 +1,20 @@
+"""
+$description Turkish live TV channels and video on-demand service from Dogan Group, including CNN Turk and Kanal D.
+$url cnnturk.com
+$url dreamturk.com.tr
+$url dreamtv.com.tr
+$url kanald.com.tr
+$url teve2.com.tr
+$type live, vod
+"""
+
 import logging
 import re
 from urllib.parse import urljoin
 
 from streamlink.plugin import Plugin, pluginmatcher
 from streamlink.plugin.api import validate
-from streamlink.stream import HLSStream
+from streamlink.stream.hls import HLSStream
 
 log = logging.getLogger(__name__)
 
