@@ -1,8 +1,16 @@
+"""
+$description Live TV channels from TVP, a Polish public, state-owned broadcaster.
+$url tvpstream.vod.tvp.pl
+$type live
+$region Poland
+"""
+
 import logging
 import re
 
 from streamlink.plugin import Plugin, PluginError, pluginmatcher
-from streamlink.stream import HLSStream, HTTPStream
+from streamlink.stream.hls import HLSStream
+from streamlink.stream.http import HTTPStream
 
 log = logging.getLogger(__name__)
 
