@@ -45,7 +45,6 @@ log = logging.getLogger(__name__)
 class YouTube(Plugin):
     _re_ytInitialData = re.compile(r"""var\s+ytInitialData\s*=\s*({.*?})\s*;\s*</script>""", re.DOTALL)
     _re_ytInitialPlayerResponse = re.compile(r"""var\s+ytInitialPlayerResponse\s*=\s*({.*?});\s*var\s+\w+\s*=""", re.DOTALL)
-    _re_mime_type = re.compile(r"""^(?P<type>\w+)/(?P<container>\w+); codecs="(?P<codecs>.+)"$""")
 
     _url_canonical = "https://www.youtube.com/watch?v={video_id}"
     _url_channelid_live = "https://www.youtube.com/channel/{channel_id}/live"
@@ -148,7 +147,7 @@ class YouTube(Plugin):
             validate.get("playabilityStatus"),
             validate.union_get("status", "reason")
         )
-        return validate.validate(schema, data)
+        return schema.validate(data)
 
     @classmethod
     def _schema_videodetails(cls, data):
@@ -188,7 +187,7 @@ class YouTube(Plugin):
                 ("videoDetails", "isLive")
             )
         )
-        videoDetails = validate.validate(schema, data)
+        videoDetails = schema.validate(data)
         log.trace(f"videoDetails = {videoDetails!r}")
         return videoDetails
 
@@ -210,7 +209,7 @@ class YouTube(Plugin):
                         "itag": int,
                         "mimeType": validate.all(
                             str,
-                            validate.transform(cls._re_mime_type.search),
+                            validate.regex(re.compile(r"""^(?P<type>\w+)/(?P<container>\w+); codecs="(?P<codecs>.+)"$""")),
                             validate.union_get("type", "codecs"),
                         ),
                         validate.optional("url"): validate.url(scheme="http"),
@@ -222,7 +221,7 @@ class YouTube(Plugin):
             validate.get("streamingData"),
             validate.union_get("hlsManifestUrl", "formats", "adaptiveFormats")
         )
-        hls_manifest, formats, adaptive_formats = validate.validate(schema, data)
+        hls_manifest, formats, adaptive_formats = schema.validate(data)
         return hls_manifest, formats or [], adaptive_formats or []
 
     def _create_adaptive_streams(self, adaptive_formats):
