@@ -280,6 +280,18 @@ class HLSStreamWorker(SegmentedStreamWorker):
         elif self.playlist_reload_time_override not in ["segment", "live-edge"]:
             self.playlist_reload_time_override = 0
 
+    def _fetch_playlist(self) -> Response:
+        res = self.session.http.get(
+            self.stream.url,
+            exception=StreamError,
+            retries=self.playlist_reload_retries,
+            **self.reader.request_params,
+        )
+        res.encoding = "utf-8"
+
+        return res
+
+    # TODO: rename to _parse_playlist
     def _reload_playlist(self, *args, **kwargs):
         return load_hls_playlist(*args, **kwargs)
 
@@ -288,14 +300,10 @@ class HLSStreamWorker(SegmentedStreamWorker):
             return
 
         self.reader.buffer.wait_free()
+
         log.debug("Reloading playlist")
-        res = self.session.http.get(
-            self.stream.url,
-            exception=StreamError,
-            retries=self.playlist_reload_retries,
-            **self.reader.request_params,
-        )
-        res.encoding = "utf-8"
+        res = self._fetch_playlist()
+
         try:
             playlist = self._reload_playlist(res)
         except ValueError as err:
@@ -471,6 +479,7 @@ class MuxedHLSStream(MuxedStream):
         video: str,
         audio: Union[str, List[str]],
         url_master: Optional[str] = None,
+        multivariant: Optional[M3U8] = None,
         force_restart: bool = False,
         ffmpeg_options: Optional[Dict[str, Any]] = None,
         **args
@@ -479,7 +488,8 @@ class MuxedHLSStream(MuxedStream):
         :param streamlink.Streamlink session: Streamlink session instance
         :param video: Video stream URL
         :param audio: Audio stream URL or list of URLs
-        :param url_master: The URL of the HLS playlist's master/variant playlist
+        :param url_master: The URL of the HLS playlist's multivariant playlist (deprecated)
+        :param multivariant: The parsed multivariant playlist
         :param force_restart: Start from the beginning after reaching the playlist's end
         :param ffmpeg_options: Additional keyword arguments passed to :class:`ffmpegmux.FFMPEGMuxer`
         :param args: Additional keyword arguments passed to :class:`HLSStream`
@@ -498,13 +508,21 @@ class MuxedHLSStream(MuxedStream):
         ffmpeg_options = ffmpeg_options or {}
 
         super().__init__(session, *substreams, format="mpegts", maps=maps, **ffmpeg_options)
-        self.url_master = url_master
+        self._url_master = url_master
+        self.multivariant = multivariant if multivariant and multivariant.is_master else None
+
+    @property
+    def url_master(self):
+        """Deprecated"""
+        return self.multivariant.uri if self.multivariant and self.multivariant.uri else self._url_master
 
     def to_manifest_url(self):
-        if self.url_master is None:
+        url = self.multivariant.uri if self.multivariant and self.multivariant.uri else self.url_master
+
+        if url is None:
             return super().to_manifest_url()
 
-        return self.url_master
+        return url
 
 
 class HLSStream(HTTPStream):
@@ -520,6 +538,7 @@ class HLSStream(HTTPStream):
         session_,
         url: str,
         url_master: Optional[str] = None,
+        multivariant: Optional[M3U8] = None,
         force_restart: bool = False,
         start_offset: float = 0,
         duration: Optional[float] = None,
@@ -528,7 +547,8 @@ class HLSStream(HTTPStream):
         """
         :param streamlink.Streamlink session_: Streamlink session instance
         :param url: The URL of the HLS playlist
-        :param url_master: The URL of the HLS playlist's master/variant playlist
+        :param url_master: The URL of the HLS playlist's multivariant playlist (deprecated)
+        :param multivariant: The parsed multivariant playlist
         :param force_restart: Start from the beginning after reaching the playlist's end
         :param start_offset: Number of seconds to be skipped from the beginning
         :param duration: Number of seconds until ending the stream
@@ -536,7 +556,8 @@ class HLSStream(HTTPStream):
         """
 
         super().__init__(session_, url, **args)
-        self.url_master = url_master
+        self._url_master = url_master
+        self.multivariant = multivariant if multivariant and multivariant.is_master else None
         self.force_restart = force_restart
         self.start_offset = start_offset
         self.duration = duration
@@ -544,21 +565,29 @@ class HLSStream(HTTPStream):
     def __json__(self):
         json = super().__json__()
 
-        if self.url_master:
+        try:
             json["master"] = self.to_manifest_url()
+        except TypeError:
+            pass
 
-        # Pretty sure HLS is GET only.
         del json["method"]
         del json["body"]
 
         return json
 
+    @property
+    def url_master(self):
+        """Deprecated"""
+        return self.multivariant.uri if self.multivariant and self.multivariant.uri else self._url_master
+
     def to_manifest_url(self):
-        if self.url_master is None:
+        url = self.multivariant.uri if self.multivariant and self.multivariant.uri else self.url_master
+
+        if url is None:
             return super().to_manifest_url()
 
         args = self.args.copy()
-        args.update(url=self.url_master)
+        args.update(url=url)
 
         return self.session.http.prepare_new_request(**args).url
 
@@ -568,6 +597,14 @@ class HLSStream(HTTPStream):
 
         return reader
 
+    @classmethod
+    def _fetch_variant_playlist(cls, session, url: str, **request_params) -> Response:
+        res = session.http.get(url, exception=OSError, **request_params)
+        res.encoding = "utf-8"
+
+        return res
+
+    # TODO: rename to _parse_variant_playlist
     @classmethod
     def _get_variant_playlist(cls, *args, **kwargs):
         return load_hls_playlist(*args, **kwargs)
@@ -605,12 +642,10 @@ class HLSStream(HTTPStream):
         locale = session_.localization
         audio_select = session_.options.get("hls-audio-select") or []
 
-        # noinspection PyArgumentList
-        res = session_.http.get(url, exception=IOError, **request_params)
-        res.encoding = "utf-8"
+        res = cls._fetch_variant_playlist(session_, url, **request_params)
 
         try:
-            parser = cls._get_variant_playlist(res)
+            multivariant = cls._get_variant_playlist(res)
         except ValueError as err:
             raise OSError(f"Failed to parse playlist: {err}")
 
@@ -618,7 +653,7 @@ class HLSStream(HTTPStream):
         stream: Union["HLSStream", "MuxedHLSStream"]
         streams: Dict[str, Union["HLSStream", "MuxedHLSStream"]] = {}
 
-        for playlist in filter(lambda p: not p.is_iframe, parser.playlists):
+        for playlist in filter(lambda p: not p.is_iframe, multivariant.playlists):
             names: Dict[str, Optional[str]] = dict(name=None, pixels=None, bitrate=None)
             audio_streams = []
             fallback_audio: List[Media] = []
@@ -721,7 +756,7 @@ class HLSStream(HTTPStream):
                     session_,
                     video=playlist.uri,
                     audio=[x.uri for x in external_audio if x.uri],
-                    url_master=url,
+                    multivariant=multivariant,
                     force_restart=force_restart,
                     start_offset=start_offset,
                     duration=duration,
@@ -731,7 +766,7 @@ class HLSStream(HTTPStream):
                 stream = cls(
                     session_,
                     playlist.uri,
-                    url_master=url,
+                    multivariant=multivariant,
                     force_restart=force_restart,
                     start_offset=start_offset,
                     duration=duration,
